.wy-nav-content {
  height: auto;
  min-height: 100%;
}

@media print {
  .wy-grid-for-nav {
    height: auto;
    position: static;
  }
}

.wy-side-nav-search, .wy-nav-side {
  background-color: #14213d;
}

.wy-side-nav-search input[type=text] {
  border-radius: 0;
}

.wy-menu-vertical a:hover {
  background: #1ee494;
  color: #14213d;
}
